## Copyright (C) 2011 John W. Eaton
##
## This file is part of Octave.
##
## Octave is free software; you can redistribute it and/or modify it
## under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or (at
## your option) any later version.
##
## Octave is distributed in the hope that it will be useful, but
## WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
## General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {} iscolumn (@var{x})
## Return true if @var{x} is a column vector.
## @seealso{isrow, isscalar, isvector, ismatrix}
## @end deftypefn

## Author: Rik Wehbring

function retval = iscolumn (x)

  retval = false;

  if (nargin != 1)
    print_usage ();
  endif

  sz = size (x);
  retval = (ndims (x) == 2 && (sz(2) == 1));

endfunction

%!assert(iscolumn ([1, 2, 3]), false);
%!assert(iscolumn ([1; 2; 3]));
%!assert(iscolumn (1));
%!assert(iscolumn ([]), false);
%!assert(iscolumn ([1, 2; 3, 4]), false);

%!test
%! warning ("off", "Octave:str-to-num");
%! assert((iscolumn ("t")));
%!test
%! warning ("off", "Octave:str-to-num");
%! assert(!(iscolumn ("test")));

%!assert(!(iscolumn (["test"; "ing"])));

%!test
%! s.a = 1;
%! assert((iscolumn (s)));

%% Test input validation
%!error iscolumn ();
%!error iscolumn ([1, 2], 2);

